/*
** error.c
**
** Copyright (c) 1994-1995 Peter Eriksson <pen@signum.se>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>

#include "phttpd.h"


int error_bad_request(struct connectioninfo *cip,
		      const char *buf)
{
    return http_error(cip, 400, "Bad HTTP request:<BR><PRE>%s</PRE>\n", buf);
}



int error_not_found(struct connectioninfo *cip)
{
    char buf1[2048], buf2[2048];
    char *url, *request;

    
    url = url_quote(cip->hip->orig_url, buf1, sizeof(buf1), "?", 0);

    request = cip->hip->orig_request;
    if (request)
	request = url_quote(request, buf2, sizeof(buf2), "\"", 1);

    
    return http_error(cip, 404, 
      "The requested URL, <A HREF=\"%s%s%s%s\">%s%s%s%s</A>, was not found.",
		      url[0] == '/' ? server_url : "",
		      url,
		      request ? "?" : "",
		      request ? request : "",
		      server_url,
		      url,
		      request ? "?" : "",
		      request ? request : "");
}



int error_access(struct connectioninfo *cip)
{
    char buf1[2048], buf2[2048];
    char *url, *request;

    
    url = url_quote(cip->hip->orig_url, buf1, sizeof(buf1), "?", 0);
    
    request = cip->hip->request;
    if (request)
	request = url_quote(request, buf2, sizeof(buf2), "\"", 1);
    
    return http_error(cip, 403, 
		      "Acess Denied for URL <A HREF=\"%s%s%s%s\">%s%s%s%s</A>",
		      server_url,
		      url,
		      request ? "?" : "",
		      request ? request : "",
		      server_url,
		      url,
		      request ? "?" : "",
		      request ? request : "");
}


int error_system(struct connectioninfo *cip,
		 const char *prompt)
{
    return http_error(cip, 500, 
	       "A system error occured:<BR><PRE>%s: %s</PRE>",
	       prompt, strerror(errno));
}
